@@ -1,14 +1,15 @@
-from django.core.management.base import BaseCommand
-from django.contrib.auth.models import User, Group
-from django.db import transaction
-from decimal import Decimal
 import json
+from decimal import Decimal
+
+from django.contrib.auth.models import Group, User
+from django.core.management.base import BaseCommand
+from django.db import transaction
 
 from django_forms_workflows.models import (
     FormDefinition,
     FormField,
-    PrefillSource,
     PostSubmissionAction,
+    PrefillSource,
     WorkflowDefinition,
 )
 
@@ -19,12 +20,19 @@ class Command(BaseCommand):
     @transaction.atomic
     def handle(self, *args, **options):
         # Groups
-        group_names = ["Barn Managers", "Field Crew", "Equipment Operators", "Farm Owners"]
+        group_names = [
+            "Barn Managers",
+            "Field Crew",
+            "Equipment Operators",
+            "Farm Owners",
+        ]
         groups = {}
         for name in group_names:
             g, _ = Group.objects.get_or_create(name=name)
             groups[name] = g
-        self.stdout.write(self.style.SUCCESS(f"Ensured groups: {', '.join(group_names)}"))
+        self.stdout.write(
+            self.style.SUCCESS(f"Ensured groups: {', '.join(group_names)}")
+        )
 
         # Users
         users_spec = [
@@ -62,19 +70,28 @@ class Command(BaseCommand):
 
         created_users = []
         for spec in users_spec:
-            user, created = User.objects.get_or_create(username=spec["username"], defaults={
-                "email": spec.get("email", ""),
-                "first_name": spec.get("first_name", ""),
-                "last_name": spec.get("last_name", ""),
-                "is_staff": spec.get("is_staff", False),
-                "is_superuser": spec.get("is_superuser", False),
-            })
+            user, created = User.objects.get_or_create(
+                username=spec["username"],
+                defaults={
+                    "email": spec.get("email", ""),
+                    "first_name": spec.get("first_name", ""),
+                    "last_name": spec.get("last_name", ""),
+                    "is_staff": spec.get("is_staff", False),
+                    "is_superuser": spec.get("is_superuser", False),
+                },
+            )
             if created:
                 user.set_password("farm123")
                 user.save()
             # Ensure attributes in case the user existed
             updated = False
-            for attr in ("email", "first_name", "last_name", "is_staff", "is_superuser"):
+            for attr in (
+                "email",
+                "first_name",
+                "last_name",
+                "is_staff",
+                "is_superuser",
+            ):
                 val = spec.get(attr, getattr(user, attr))
                 if getattr(user, attr) != val:
                     setattr(user, attr, val)
@@ -86,7 +103,11 @@ class Command(BaseCommand):
             for gname in spec.get("groups", []):
                 user.groups.add(groups[gname])
             created_users.append(user.username)
-        self.stdout.write(self.style.SUCCESS(f"Users ready: {', '.join(created_users)} (password: farm123)"))
+        self.stdout.write(
+            self.style.SUCCESS(
+                f"Users ready: {', '.join(created_users)} (password: farm123)"
+            )
+        )
 
         # Forms and Workflows
         # 1) Equipment Repair Request (any approver, escalates over $1000)
@@ -99,30 +120,64 @@ class Command(BaseCommand):
             },
         )
         if created:
-            self.stdout.write(self.style.SUCCESS("Created form: Equipment Repair Request"))
+            self.stdout.write(
+                self.style.SUCCESS("Created form: Equipment Repair Request")
+            )
         if fd1.fields.count() == 0:
-            FormField.objects.bulk_create([
-                FormField(form_definition=fd1, field_name="equipment_name", field_label="Equipment",
-                          field_type="text", required=True, order=1, placeholder="e.g., Tractor #12"),
-                FormField(form_definition=fd1, field_name="issue_description", field_label="Issue Description",
-                          field_type="textarea", required=True, order=2),
-                FormField(form_definition=fd1, field_name="cost_estimate", field_label="Estimated Cost",
-                          field_type="decimal", required=False, order=3),
-                FormField(form_definition=fd1, field_name="priority", field_label="Priority",
-                          field_type="select", required=True, order=4,
-                          choices=[
-                              {"value": "low", "label": "Low"},
-                              {"value": "medium", "label": "Medium"},
-                              {"value": "high", "label": "High"},
-                          ]),
-            ])
-            self.stdout.write(self.style.SUCCESS("Added fields for Equipment Repair Request"))
-        wf1, _ = WorkflowDefinition.objects.get_or_create(form_definition=fd1, defaults={
-            "requires_approval": True,
-            "approval_logic": "any",
-            "approval_deadline_days": 7,
-            "send_reminder_after_days": 3,
-        })
+            FormField.objects.bulk_create(
+                [
+                    FormField(
+                        form_definition=fd1,
+                        field_name="equipment_name",
+                        field_label="Equipment",
+                        field_type="text",
+                        required=True,
+                        order=1,
+                        placeholder="e.g., Tractor #12",
+                    ),
+                    FormField(
+                        form_definition=fd1,
+                        field_name="issue_description",
+                        field_label="Issue Description",
+                        field_type="textarea",
+                        required=True,
+                        order=2,
+                    ),
+                    FormField(
+                        form_definition=fd1,
+                        field_name="cost_estimate",
+                        field_label="Estimated Cost",
+                        field_type="decimal",
+                        required=False,
+                        order=3,
+                    ),
+                    FormField(
+                        form_definition=fd1,
+                        field_name="priority",
+                        field_label="Priority",
+                        field_type="select",
+                        required=True,
+                        order=4,
+                        choices=[
+                            {"value": "low", "label": "Low"},
+                            {"value": "medium", "label": "Medium"},
+                            {"value": "high", "label": "High"},
+                        ],
+                    ),
+                ]
+            )
+            self.stdout.write(
+                self.style.SUCCESS("Added fields for Equipment Repair Request")
+            )
+        wf1, _ = WorkflowDefinition.objects.get_or_create(
+            form_definition=fd1,
+            defaults={
+                "requires_approval": True,
+                "approval_logic": "any",
+                "approval_deadline_days": 7,
+                "send_reminder_after_days": 3,
+            },
+        )
         # Ensure associations and settings
         wf1.requires_approval = True
         wf1.approval_logic = "any"
@@ -131,9 +186,13 @@ class Command(BaseCommand):
         wf1.escalation_field = "cost_estimate"
         wf1.escalation_threshold = Decimal("1000.00")
         wf1.save()
-        wf1.approval_groups.set([groups["Barn Managers"], groups["Equipment Operators"]])
+        wf1.approval_groups.set(
+            [groups["Barn Managers"], groups["Equipment Operators"]]
+        )
         wf1.escalation_groups.set([groups["Farm Owners"]])
-        self.stdout.write(self.style.SUCCESS("Configured workflow for Equipment Repair Request"))
+        self.stdout.write(
+            self.style.SUCCESS("Configured workflow for Equipment Repair Request")
+        )
 
         # 2) Barn Maintenance Request (all must approve)
         fd2, created = FormDefinition.objects.get_or_create(
@@ -145,30 +204,59 @@ class Command(BaseCommand):
             },
         )
         if created:
-            self.stdout.write(self.style.SUCCESS("Created form: Barn Maintenance Request"))
+            self.stdout.write(
+                self.style.SUCCESS("Created form: Barn Maintenance Request")
+            )
         if fd2.fields.count() == 0:
-            FormField.objects.bulk_create([
-                FormField(form_definition=fd2, field_name="maintenance_date", field_label="Preferred Date",
-                          field_type="date", required=True, order=1),
-                FormField(form_definition=fd2, field_name="area", field_label="Area/Equipment",
-                          field_type="text", required=True, order=2),
-                FormField(form_definition=fd2, field_name="details", field_label="Details",
-                          field_type="textarea", required=True, order=3),
-            ])
-            self.stdout.write(self.style.SUCCESS("Added fields for Barn Maintenance Request"))
-        wf2, _ = WorkflowDefinition.objects.get_or_create(form_definition=fd2, defaults={
-            "requires_approval": True,
-            "approval_logic": "all",
-            "approval_deadline_days": 5,
-            "send_reminder_after_days": 2,
-        })
+            FormField.objects.bulk_create(
+                [
+                    FormField(
+                        form_definition=fd2,
+                        field_name="maintenance_date",
+                        field_label="Preferred Date",
+                        field_type="date",
+                        required=True,
+                        order=1,
+                    ),
+                    FormField(
+                        form_definition=fd2,
+                        field_name="area",
+                        field_label="Area/Equipment",
+                        field_type="text",
+                        required=True,
+                        order=2,
+                    ),
+                    FormField(
+                        form_definition=fd2,
+                        field_name="details",
+                        field_label="Details",
+                        field_type="textarea",
+                        required=True,
+                        order=3,
+                    ),
+                ]
+            )
+            self.stdout.write(
+                self.style.SUCCESS("Added fields for Barn Maintenance Request")
+            )
+        wf2, _ = WorkflowDefinition.objects.get_or_create(
+            form_definition=fd2,
+            defaults={
+                "requires_approval": True,
+                "approval_logic": "all",
+                "approval_deadline_days": 5,
+                "send_reminder_after_days": 2,
+            },
+        )
         wf2.requires_approval = True
         wf2.approval_logic = "all"
         wf2.approval_deadline_days = 5
         wf2.send_reminder_after_days = 2
         wf2.save()
         wf2.approval_groups.set([groups["Field Crew"], groups["Barn Managers"]])
-        self.stdout.write(self.style.SUCCESS("Configured workflow for Barn Maintenance Request"))
+        self.stdout.write(
+            self.style.SUCCESS("Configured workflow for Barn Maintenance Request")
+        )
 
         # 3) Harvest Report (no approval)
         fd3, created = FormDefinition.objects.get_or_create(
@@ -182,14 +270,34 @@ class Command(BaseCommand):
         if created:
             self.stdout.write(self.style.SUCCESS("Created form: Harvest Report"))
         if fd3.fields.count() == 0:
-            FormField.objects.bulk_create([
-                FormField(form_definition=fd3, field_name="date", field_label="Date",
-                          field_type="date", required=True, order=1),
-                FormField(form_definition=fd3, field_name="crop", field_label="Crop",
-                          field_type="text", required=True, order=2),
-                FormField(form_definition=fd3, field_name="quantity", field_label="Quantity (lbs)",
-                          field_type="number", required=True, order=3),
-            ])
+            FormField.objects.bulk_create(
+                [
+                    FormField(
+                        form_definition=fd3,
+                        field_name="date",
+                        field_label="Date",
+                        field_type="date",
+                        required=True,
+                        order=1,
+                    ),
+                    FormField(
+                        form_definition=fd3,
+                        field_name="crop",
+                        field_label="Crop",
+                        field_type="text",
+                        required=True,
+                        order=2,
+                    ),
+                    FormField(
+                        form_definition=fd3,
+                        field_name="quantity",
+                        field_label="Quantity (lbs)",
+                        field_type="number",
+                        required=True,
+                        order=3,
+                    ),
+                ]
+            )
             self.stdout.write(self.style.SUCCESS("Added fields for Harvest Report"))
 
         # 4) Farmer Contact Update (showcases prefill functionality)
@@ -206,10 +314,10 @@ class Command(BaseCommand):
 
         # Get prefill sources
         try:
-            prefill_email = PrefillSource.objects.get(source_key='user.email')
-            prefill_first_name = PrefillSource.objects.get(source_key='user.first_name')
-            prefill_last_name = PrefillSource.objects.get(source_key='user.last_name')
-            prefill_current_date = PrefillSource.objects.get(source_key='current_date')
+            prefill_email = PrefillSource.objects.get(source_key="user.email")
+            prefill_first_name = PrefillSource.objects.get(source_key="user.first_name")
+            prefill_last_name = PrefillSource.objects.get(source_key="user.last_name")
+            prefill_current_date = PrefillSource.objects.get(source_key="current_date")
         except PrefillSource.DoesNotExist:
             self.stdout.write(
                 self.style.WARNING(
@@ -228,7 +336,7 @@ class Command(BaseCommand):
                     field_name="section_personal",
                     field_label="Personal Information",
                     field_type="section",
-                    order=1
+                    order=1,
                 ),
                 FormField(
                     form_definition=fd4,
@@ -239,7 +347,7 @@ class Command(BaseCommand):
                     order=2,
                     width="half",
                     help_text="Auto-filled from your account",
-                    prefill_source_config=prefill_first_name
+                    prefill_source_config=prefill_first_name,
                 ),
                 FormField(
                     form_definition=fd4,
@@ -250,7 +358,7 @@ class Command(BaseCommand):
                     order=3,
                     width="half",
                     help_text="Auto-filled from your account",
-                    prefill_source_config=prefill_last_name
+                    prefill_source_config=prefill_last_name,
                 ),
                 FormField(
                     form_definition=fd4,
@@ -260,14 +368,14 @@ class Command(BaseCommand):
                     required=True,
                     order=4,
                     help_text="Auto-filled from your account",
-                    prefill_source_config=prefill_email
+                    prefill_source_config=prefill_email,
                 ),
                 FormField(
                     form_definition=fd4,
                     field_name="section_contact",
                     field_label="Contact Details",
                     field_type="section",
-                    order=5
+                    order=5,
                 ),
                 FormField(
                     form_definition=fd4,
@@ -276,7 +384,7 @@ class Command(BaseCommand):
                     field_type="text",
                     required=False,
                     order=6,
-                    placeholder="(555) 123-4567"
+                    placeholder="(555) 123-4567",
                 ),
                 FormField(
                     form_definition=fd4,
@@ -284,7 +392,7 @@ class Command(BaseCommand):
                     field_label="Mailing Address",
                     field_type="textarea",
                     required=False,
-                    order=7
+                    order=7,
                 ),
                 FormField(
                     form_definition=fd4,
@@ -294,11 +402,15 @@ class Command(BaseCommand):
                     required=True,
                     order=8,
                     help_text="Auto-filled with today's date",
-                    prefill_source_config=prefill_current_date
+                    prefill_source_config=prefill_current_date,
                 ),
             ]
             FormField.objects.bulk_create(fields_to_create)
-            self.stdout.write(self.style.SUCCESS("Added fields for Farmer Contact Update (with prefill)"))
+            self.stdout.write(
+                self.style.SUCCESS(
+                    "Added fields for Farmer Contact Update (with prefill)"
+                )
+            )
 
         # Add post-submission action example for Farmer Contact Update
         # This demonstrates how to update an external system after form submission
@@ -315,63 +427,79 @@ class Command(BaseCommand):
                 "api_method": "POST",
                 "api_headers": {
                     "Content-Type": "application/json",
-                    "X-Demo-Header": "FarmDemo"
+                    "X-Demo-Header": "FarmDemo",
                 },
-                "api_body_template": json.dumps({
-                    "event": "contact_update",
-                    "user": "{username}",
-                    "email": "{email}",
-                    "phone": "{phone}",
-                    "timestamp": "{update_date}"
-                }, indent=2),
+                "api_body_template": json.dumps(
+                    {
+                        "event": "contact_update",
+                        "user": "{username}",
+                        "email": "{email}",
+                        "phone": "{phone}",
+                        "timestamp": "{update_date}",
+                    },
+                    indent=2,
+                ),
                 "fail_silently": True,
                 "retry_on_failure": False,
-            }
+            },
         )
         if created:
-            self.stdout.write(self.style.SUCCESS("Created demo post-submission action (API call)"))
+            self.stdout.write(
+                self.style.SUCCESS("Created demo post-submission action (API call)")
+            )
 
-        # Add another example for database update (commented out since it requires external DB)
+        # Add database update action to update User model
         db_action, created = PostSubmissionAction.objects.get_or_create(
             form_definition=fd4,
-            name="Update Contact Database",
+            name="Update User Profile",
             defaults={
                 "action_type": "database",
-                "trigger": "on_approve",
-                "description": "Update external contact database after approval (demo - disabled)",
-                "is_active": False,  # Disabled by default
+                "trigger": "on_submit",
+                "description": "Update user profile in database when contact info is submitted",
+                "is_active": True,  # Enabled for demo
                 "order": 2,
-                "db_alias": "default",  # Would be external DB in production
-                "db_schema": "public",
-                "db_table": "contacts",
-                "db_lookup_field": "user_id",
+                "db_alias": "default",
+                "db_schema": "",  # SQLite doesn't use schemas
+                "db_table": "auth_user",
+                "db_lookup_field": "id",
                 "db_user_field": "id",
                 "db_field_mappings": [
+                    {"form_field": "first_name", "db_column": "first_name"},
+                    {"form_field": "last_name", "db_column": "last_name"},
                     {"form_field": "email", "db_column": "email"},
-                    {"form_field": "phone", "db_column": "phone"},
-                    {"form_field": "address", "db_column": "address"},
                 ],
-                "fail_silently": True,
+                "fail_silently": False,
                 "retry_on_failure": True,
                 "max_retries": 3,
-            }
+            },
         )
         if created:
-            self.stdout.write(self.style.SUCCESS("Created demo post-submission action (Database update)"))
+            self.stdout.write(
+                self.style.SUCCESS(
+                    "Created demo post-submission action (Database update)"
+                )
+            )
 
         self.stdout.write(self.style.SUCCESS("\n🌾 Farm demo seed complete! 🌾"))
         self.stdout.write("\nAvailable forms:")
-        self.stdout.write("  1. Equipment Repair Request - Showcases escalation workflow")
-        self.stdout.write("  2. Barn Maintenance Request - Showcases 'all must approve' workflow")
+        self.stdout.write(
+            "  1. Equipment Repair Request - Showcases escalation workflow"
+        )
+        self.stdout.write(
+            "  2. Barn Maintenance Request - Showcases 'all must approve' workflow"
+        )
         self.stdout.write("  3. Harvest Report - No approval required")
-        self.stdout.write("  4. Farmer Contact Update - Showcases prefill & post-submission actions")
+        self.stdout.write(
+            "  4. Farmer Contact Update - Showcases prefill & post-submission actions"
+        )
         self.stdout.write("\nLogin with any user (password: farm123):")
         self.stdout.write("  • farmer_brown (admin)")
         self.stdout.write("  • farmer_jane")
         self.stdout.write("  • mechanic_mike")
         self.stdout.write("  • owner_olive")
-        self.stdout.write("\nPost-submission actions (disabled by default):")
-        self.stdout.write("  • API Call - Log contact updates to external API")
-        self.stdout.write("  • Database Update - Update external contact database")
-        self.stdout.write("  Enable in Admin → Post-Submission Actions to test")
-
+        self.stdout.write("\nPost-submission actions:")
+        self.stdout.write("  • Update User Profile - Updates auth_user table (ENABLED)")
+        self.stdout.write(
+            "  • API Call - Log contact updates to external API (disabled)"
+        )
+        self.stdout.write("  View in Admin → Post-Submission Actions")
